@@ -2,7 +2,7 @@
 ##############################################################################
 #       Copyright (C) 2010, Joel B. Mohler <joel@kiwistrawberry.us>
 #
-#  Distributed under the terms of the GNU General Public License (GPL)
+#  Distributed under the terms of the GNU Lesser General Public License (LGPL)
 #                  http://www.gnu.org/licenses/
 ##############################################################################
 """
@@ -19,13 +19,13 @@ the first.
     ...     sip.setapi('QVariant', 2)
 """
 
-qt_bindings = 'PyQt4'
+qt_bindings = 'PySide'
 if qt_bindings == 'PyQt4':
     # we wish to only touch sip if we're PyQt4 based (otherwise sip is unnecessary)
     import sip
     sip.setapi('QString', 2)
     sip.setapi('QVariant', 2)
-from PyQt4 import QtGui,QtCore
+from PySide import QtGui,QtCore
 import datetime
 import decimal
 import re
@@ -91,14 +91,16 @@ def fromQType(v, suggested=None):
 
     return v
 
-def toQType(v,suggested=None):
+def toQType(v, suggested=None, empty_zero=False):
     """
-    This function takes a native python object and returns it in the most faithful way as a PyQt/PySide type.  
-    For API 2, this means that basic types like str and int are returned unchanged.
+    This function takes a native python object and returns it in the most
+    faithful way as a PyQt/PySide type.  For API 2, this means that basic types
+    like str and int are returned unchanged.
     
-    One notable caveat is that Qt does not have a decimal type so objects of type decimal.Decimal are returned 
-    as strings.  The rationale for this is that maintaining decimal exactness of decimals is almost always the 
-    right thing.
+    One notable caveat is that Qt does not have a decimal type so objects of
+    type decimal.Decimal are returned as strings.  The rationale for this is
+    that maintaining decimal exactness of decimals is almost always the right
+    thing.
     
     Examples:
     >>> type(toQType(12))
@@ -110,7 +112,8 @@ def toQType(v,suggested=None):
     >>> type(toQType(datetime.date(1979,1,9))) is QtCore.QDate
     True
 
-    When the value `v` is None, we return a blank version of the suggested type.
+    When the value `v` is None, we return a blank version of the suggested
+    type.
 
     >>> toQType(None,suggested=str)
     ''
@@ -120,7 +123,10 @@ def toQType(v,suggested=None):
     if isinstance(v, datetime.date):
         v = QtCore.QDate(v.year,v.month,v.day)
     elif isinstance(v, decimal.Decimal):
-        v = str(v)
+        if empty_zero and v == 0: 
+            v = ""
+        else:
+            v = str(v)
 
     if v is None and suggested is not None:
         if suggested == datetime.date:
@@ -130,6 +136,9 @@ def toQType(v,suggested=None):
             # but the whole point here is to return Qt type!
             v = suggested()
 
+    if type(v) in [int, float] and empty_zero and v == 0:
+        return ""
+
     return v
 
 def ButtonBoxButton(bb,b,role=None):
