@@ -2,7 +2,7 @@
 ##############################################################################
 #       Copyright (C) 2010, Joel B. Mohler <joel@kiwistrawberry.us>
 #
-#  Distributed under the terms of the GNU General Public License (GPL)
+#  Distributed under the terms of the GNU Lesser General Public License (LGPL)
 #                  http://www.gnu.org/licenses/
 ##############################################################################
 """
@@ -15,7 +15,7 @@ and sorting the commands for global application consistency.
 import weakref
 import inspect
 from PyQtHelpers import *
-from PyQt4 import QtCore, QtGui
+from PySide import QtCore, QtGui
 
 DROP_ACTION_TYPE="drop-action"
 
@@ -65,6 +65,10 @@ class Command(object):
 
         action = QtGui.QAction(self.descr, parent)
         if self.key is not None:
+            # type promotion to get around
+            # https://bugreports.qt-project.org/browse/PYSIDE-19
+            if isinstance(self.key, QtCore.Qt.Key):
+                self.key = QtGui.QKeySequence(self.key)
             action.setShortcut(self.key)
         if self.statusTip is not None:
             action.setStatusTip(parent.tr(self.statusTip))
@@ -297,6 +301,7 @@ class BoundCommandMenuItem(object):
         self.action = action
         self.objectConverter = objectConverter
         self.binding = binding
+        self.model = None
 
         if binding.view is not None:
             self.model = binding.view.model()
@@ -371,7 +376,7 @@ class BoundCommandMenuItem(object):
             import warnings
             warnings.warn("No selected view index for {0}".format(self.cmd.name))
         else:
-            if self.cmd.viewRelated:
+            if self.cmd.viewRelated and self.model is not None:
                 handle = index
                 if handle is not None:
                     handle = handle.internalPointer()
