@@ -2,29 +2,102 @@
 ##############################################################################
 #       Copyright (C) 2011, Joel B. Mohler <joel@kiwistrawberry.us>
 #
-#  Distributed under the terms of the GNU General Public License (GPL)
+#  Distributed under the terms of the GNU Lesser General Public License (LGPL)
 #                  http://www.gnu.org/licenses/
 ##############################################################################
 
 from qtalchemy.widgets import PBKeyEdit
 from user_attr import UserAttr
-from PyQt4 import QtCore, QtGui
+from PySide import QtCore, QtGui
 from sqlalchemy.orm import mapper, create_session, relation, object_session, Query
 from PyQtModels import QueryTableModel, attrReadonly
 from input_yoke import InputYoke
 
-class RowWidgetEventProxy(object):
-    """
-    This proxy manages call-backs from bound widgets and forwards them to a 
-    virtual method in the column definition.
-    """
-    def __init__(self, widget, row, userattr):
-        self.widget = widget
-        self.row = row
-        self.userattr = userattr
+class PopupKeyListing(PBKeyEdit):
+    def __init__(self, parent, Session, foreignAttr):
+        PBKeyEdit.__init__(self, parent)
+
+        self.Session = Session
+        self.foreignAttr = foreignAttr
+        self.popupList = None
+
+        self.textEdited.connect(self.refinePopup)
+        self.buttonPressed.connect(self.search)
+
+        self._initPopup()
+
+    def _initPopup(self):
+        if self.popupList is not None:
+            return
+
+        # configure the popup view as a popup
+        # lots of logic copied from http://qt.gitorious.org/qt/qt/blobs/4.7/src/gui/util/qcompleter.cpp
+        self.popupList = QtGui.QListView()
+        self.popupList.setParent(None, QtCore.Qt.Popup)
+        self.popupList.setFocusPolicy(QtCore.Qt.NoFocus)
+        self.popupList.setFocusProxy(self)
+        self.popupList.installEventFilter(self)
+
+        self.popupList.clicked.connect(self.modelSelection)
+        self.popupList.activated.connect(self.modelSelection)
+
+        self.query = self.foreignAttr.getSelection()
+        self.popupModel = QueryTableModel(self.query, ['name'])
+        self.popupList.setModel(self.popupModel)
+
+    def shutdown(self, obj):
+        if self.popupList is not None:
+            self.popupList.hide()
+            self.popupList.close()
+            self.popupList = None
+
+    def event(self, e):
+        if e.type() in [QtCore.QEvent.Hide]:
+            self.shutdown(self)
+        return PBKeyEdit.event(self, e)
+
+    def eventFilter(self, o, e):
+        if o is not self.popupList:
+            return PBKeyEdit.eventFilter(self, o, e)
+
+        if e.type() == QtCore.QEvent.KeyPress:
+            if e.key() == QtCore.Qt.Key_Escape:
+                self.popupList.hide()
+                return True
+
+            self.event(e)
+            if e.isAccepted():
+                return True
+
+        if e.type() == QtCore.QEvent.MouseButtonPress:
+            if self.popupList.isVisible() and not self.popupList.underMouse():
+                self.popupList.hide()
+
+        return False
+
+    def modelSelection(self, index):
+        self.setText(index.internalPointer().name)
+        self.popupList.hide()
+
+    def refinePopup(self, text):
+        q = self.query.filter(self.foreignAttr.keyCol().ilike('{0}%'.format(text.replace('%', '%%'))))
+        session = self.Session()
+        q.session = session
+        keys = q.limit(10).all()
+        session.close()
+
+        if len(keys) > 0:
+            self.popupModel.reset_content_from_list(keys)
+            rect = self.rect()
+            self.popupList.move(self.mapToGlobal(rect.bottomLeft()))
+            self.popupList.show()
+            self.setFocus(QtCore.Qt.PopupFocusReason)
+        else:
+            self.popupList.hide()
 
     def search(self):
-        self.userattr.search(self.widget, self.row)
+        self.foreignAttr.search(self, self.row)
+
 
 class ForeignKeyReferral(UserAttr):
     """
@@ -66,14 +139,18 @@ class ForeignKeyReferral(UserAttr):
             return
         s = self.session(row)
         try:
-            # we use ilike to complement the QtCore.Qt.CaseInsensitive in the QCompleter
+            # we use ilike to complement the QtCore.Qt.CaseInsensitive in the
+            # QCompleter
             setattr(row,self.backref,s.query(self.class_).filter(getattr(self.class_,self.userkey).ilike(value)).one())
         except Exception as e:
             print e
             setattr(row,self.backref,None)
 
+    def keyCol(self):
+        return getattr(self.class_, self.userkey)
+
     def getSelection(self):
-        q=Query((getattr(self.class_,self.userkey).label("name"),))
+        q=Query((self.keyCol().label("name"),))
         if self.filter_query:
             q = self.filter_query(q)
         return q
@@ -84,13 +161,15 @@ class ForeignKeyReferral(UserAttr):
         else:
             return "foreign_key"
 
-    def WidgetFactory(self,parent, index):
-        # Note that it's not entirely clear to me what criteria is appropriate for selecting a PBKeyEdit or a QComboBox.
+    def WidgetFactory(self, parent, index):
+        # Note that it's not entirely clear to me what criteria is appropriate
+        # for selecting a PBKeyEdit or a QComboBox.
         if self.entityCls is not None:
-            w = PBKeyEdit(parent)
+            w = PopupKeyListing(parent, None, self)
             w.model_index = index
-            # The PBKeyEdit has a 'search button' which offers a more comprensive notion of a list of options.
-            # The attached entityCls is expected to know what data to display in the search list.
+            # The PBKeyEdit has a 'search button' which offers a more
+            # comprensive notion of a list of options.  The attached entityCls
+            # is expected to know what data to display in the search list.
         else:
             # Some days we think this should be a combo-box.
             w = QtGui.QComboBox(parent)
@@ -99,36 +178,15 @@ class ForeignKeyReferral(UserAttr):
 
     def WidgetBind(self,widget,row):
         Session = self.session_maker(row)
-        # TODO: this is a very bad performance problem on large data-sets.
-        # I suspect we need a highly customized completer so as to only load the parts with this prefix.
-        col_model = QueryTableModel(self.getSelection(),ssrc=Session)
-        col_model.reset_content_from_session()
 
         # note that a PBKeyEdit is a QLineEdit
-        if isinstance(widget, PBKeyEdit):
-            # A widget can never be associated with more than one proxy.
-            # I believe this is a natural sort of limitation as any specific bound 'edit-type' widget can only be bound to one row at a time.
-            p = RowWidgetEventProxy(widget, row, self)
-            self.proxies[id(widget)] = p # need to hold the proxies in memory
-            widget.buttonPressed.connect(p.search)
-
-        # I handle both QLineEdit and QComboBox here.
-        if isinstance(widget,QtGui.QLineEdit):
-            col_completer = QtGui.QCompleter()
-
-            # The default QtGui.QCompleter.PopupCompletion is perhaps better
-            # QtGui.QCompleter.InlineCompletion mode made the following bug:
-            #  1)  tab through a dialog to PBKeyEdit on a table
-            #  2)  observe that the text is fully selected in the PBKeyEdit
-            #  3)  press enter
-            #  4)  text updated in the model to the first item in col_model
-            #  We presume that enter triggered the completion with the text before the input block (i.e. an empty string)
-            #col_completer.setCompletionMode(QtGui.QCompleter.InlineCompletion)
-            col_completer.setCaseSensitivity(QtCore.Qt.CaseInsensitive)
-            widget.setCompleter(col_completer)
-            #widget.setValidator(ForeignKeyValidator(fk=col_type,session=session))
-            col_completer.setModel(col_model)
-        elif isinstance(widget,QtGui.QComboBox):
+        if isinstance(widget, PopupKeyListing):
+            widget.Session = Session
+            widget.row = row
+        
+        if isinstance(widget,QtGui.QComboBox):
+            col_model = QueryTableModel(self.getSelection(),ssrc=Session)
+            col_model.reset_content_from_session()
             widget.setModel(col_model)
 
     def search(self, widget, row):
@@ -158,8 +216,10 @@ class ForeignKeyReferral(UserAttr):
             #print "Selected item:  {0}\n".format(self.fget(row))
 
             if index is None:
-                # We are not a widget associated with an abstract item view and so we suppose we are a visual element on a "dialog box lifespan".
-                # Therefore the widget needs to be updated with the visual identifier of this foreign key.
+                # We are not a widget associated with an abstract item view and
+                # so we suppose we are a visual element on a "dialog box
+                # lifespan".  Therefore the widget needs to be updated with the
+                # visual identifier of this foreign key.
                 widget.setText(self.fget(row))
             else:
                 #index.model().setData(index, self.fget(row))
@@ -213,8 +273,10 @@ class ForeignKeyEditYoke(InputYoke):
             #print "Selected item:  {0}\n".format(self.fget(row))
 
             if index is None:
-                # We are not a widget associated with an abstract item view and so we suppose we are a visual element on a "dialog box lifespan".
-                # Therefore the widget needs to be updated with the visual identifier of this foreign key.
+                # We are not a widget associated with an abstract item view and
+                # so we suppose we are a visual element on a "dialog box
+                # lifespan".  Therefore the widget needs to be updated with the
+                # visual identifier of this foreign key.
                 self.widget.setText(user_attr.fget(row))
             else:
                 #index.model().setData(index, user_attr.fget(row))
