@@ -2,7 +2,7 @@
 ##############################################################################
 #       Copyright (C) 2010, Joel B. Mohler <joel@kiwistrawberry.us>
 #
-#  Distributed under the terms of the GNU General Public License (GPL)
+#  Distributed under the terms of the GNU Lesser General Public License (LGPL)
 #                  http://www.gnu.org/licenses/
 ##############################################################################
 """
@@ -12,7 +12,7 @@ The PBKeyEdit provides data sensitive editting for foreign key edits::
 - context menus - for what? (look up referenced entity)
 """
 
-from PyQt4 import QtCore, QtGui
+from PySide import QtCore, QtGui
 from button_edit import PBButtonEdit
 
 class PBKeyEdit(PBButtonEdit):
