@@ -2,11 +2,11 @@
 ##############################################################################
 #       Copyright (C) 2010, Joel B. Mohler <joel@kiwistrawberry.us>
 #
-#  Distributed under the terms of the GNU General Public License (GPL)
+#  Distributed under the terms of the GNU Lesser General Public License (LGPL)
 #                  http://www.gnu.org/licenses/
 ##############################################################################
 
-from PyQt4 import QtGui,QtCore
+from PySide import QtGui,QtCore
 import re
 from qtalchemy import *
 
@@ -184,7 +184,7 @@ class StreetAddressEdit(QtGui.QStackedWidget):
         self.addWidget(self.parsed_page)
 
         self.parseAct = QtGui.QAction("parse/concat",self)
-        self.parseAct.setShortcut(QtCore.Qt.Key_F4)
+        self.parseAct.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_F4))
         self.parseAct.triggered.connect(self.parse_or_concat)
         self.addAction(self.parseAct)
 
