@@ -2,11 +2,11 @@
 ##############################################################################
 #       Copyright (C) 2010, Joel B. Mohler <joel@kiwistrawberry.us>
 #
-#  Distributed under the terms of the GNU General Public License (GPL)
+#  Distributed under the terms of the GNU Lesser General Public License (LGPL)
 #                  http://www.gnu.org/licenses/
 ##############################################################################
 
-from PyQt4 import QtCore, QtGui
+from PySide import QtCore, QtGui
 from qtalchemy import fromQType, modelMimeRectangle, writeTableColumnGeo, readTableColumnGeo
 from viewbase import ViewBase
 
@@ -100,7 +100,6 @@ class TableView(QtGui.QTableView, ViewBase):
                 index = self.currentIndex()
                 model = self.model()
                 while iterations < cell_max:
-                    print iterations
                     iterations += 1
                     candidate = self.prevIndex(index)
                     if (model.flags(candidate) & QtCore.Qt.ItemIsEditable) == QtCore.Qt.ItemIsEditable:
